@@ -18,7 +18,7 @@
 
 __all__ = ["cli", "rest"]
 
-GIT_TAG = 'gracedb-1.19-1'
+GIT_TAG = 'gracedb-1.19.1-1'
 
 # issue 717.  Required for backward compatibility -- make sure "from ligo import gracedb"
 # works as it used to.
